==> istio-model-v1alpha3-5.12.4-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPMatchRequestBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class HTTPMatchRequestBuilder extends io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequestFluentImpl<io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequestBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequest,io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequestBuilder>{
  public HTTPMatchRequestBuilder() {
    this(false);
  }
  public HTTPMatchRequestBuilder(java.lang.Boolean validationEnabled) {
    this(new HTTPMatchRequest(), validationEnabled);
  }
  public HTTPMatchRequestBuilder(io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequestFluent<?> fluent) {
    this(fluent, false);
  }
  public HTTPMatchRequestBuilder(io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequestFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HTTPMatchRequest(), validationEnabled);
  }
  public HTTPMatchRequestBuilder(io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequestFluent<?> fluent,io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequest instance) {
    this(fluent, instance, false);
  }
  public HTTPMatchRequestBuilder(io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequestFluent<?> fluent,io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequest instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAuthority(instance.getAuthority()); 
    fluent.withGateways(instance.getGateways()); 
    fluent.withHeaders(instance.getHeaders()); 
    fluent.withIgnoreUriCase(instance.getIgnoreUriCase()); 
    fluent.withMethod(instance.getMethod()); 
    fluent.withName(instance.getName()); 
    fluent.withPort(instance.getPort()); 
    fluent.withQueryParams(instance.getQueryParams()); 
    fluent.withScheme(instance.getScheme()); 
    fluent.withSourceLabels(instance.getSourceLabels()); 
    fluent.withSourceNamespace(instance.getSourceNamespace()); 
    fluent.withUri(instance.getUri()); 
    fluent.withWithoutHeaders(instance.getWithoutHeaders()); 
    this.validationEnabled = validationEnabled; 
  }
  public HTTPMatchRequestBuilder(io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequest instance) {
    this(instance,false);
  }
  public HTTPMatchRequestBuilder(io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequest instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAuthority(instance.getAuthority()); 
    this.withGateways(instance.getGateways()); 
    this.withHeaders(instance.getHeaders()); 
    this.withIgnoreUriCase(instance.getIgnoreUriCase()); 
    this.withMethod(instance.getMethod()); 
    this.withName(instance.getName()); 
    this.withPort(instance.getPort()); 
    this.withQueryParams(instance.getQueryParams()); 
    this.withScheme(instance.getScheme()); 
    this.withSourceLabels(instance.getSourceLabels()); 
    this.withSourceNamespace(instance.getSourceNamespace()); 
    this.withUri(instance.getUri()); 
    this.withWithoutHeaders(instance.getWithoutHeaders()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequestFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.istio.api.networking.v1alpha3.HTTPMatchRequest build() {
    HTTPMatchRequest buildable = new HTTPMatchRequest(fluent.getAuthority(),fluent.getGateways(),fluent.getHeaders(),fluent.getIgnoreUriCase(),fluent.getMethod(),fluent.getName(),fluent.getPort(),fluent.getQueryParams(),fluent.getScheme(),fluent.getSourceLabels(),fluent.getSourceNamespace(),fluent.getUri(),fluent.getWithoutHeaders());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPMatchRequestBuilder that = (HTTPMatchRequestBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> istio-model-v1alpha3-6.3.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPMatchRequestBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HTTPMatchRequestBuilder extends HTTPMatchRequestFluentImpl<HTTPMatchRequestBuilder> implements VisitableBuilder<HTTPMatchRequest,HTTPMatchRequestBuilder>{
  public HTTPMatchRequestBuilder() {
    this(false);
  }
  public HTTPMatchRequestBuilder(Boolean validationEnabled) {
    this(new HTTPMatchRequest(), validationEnabled);
  }
  public HTTPMatchRequestBuilder(HTTPMatchRequestFluent<?> fluent) {
    this(fluent, false);
  }
  public HTTPMatchRequestBuilder(HTTPMatchRequestFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HTTPMatchRequest(), validationEnabled);
  }
  public HTTPMatchRequestBuilder(HTTPMatchRequestFluent<?> fluent,HTTPMatchRequest instance) {
    this(fluent, instance, false);
  }
  public HTTPMatchRequestBuilder(HTTPMatchRequestFluent<?> fluent,HTTPMatchRequest instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAuthority(instance.getAuthority()); 
    fluent.withGateways(instance.getGateways()); 
    fluent.withHeaders(instance.getHeaders()); 
    fluent.withIgnoreUriCase(instance.getIgnoreUriCase()); 
    fluent.withMethod(instance.getMethod()); 
    fluent.withName(instance.getName()); 
    fluent.withPort(instance.getPort()); 
    fluent.withQueryParams(instance.getQueryParams()); 
    fluent.withScheme(instance.getScheme()); 
    fluent.withSourceLabels(instance.getSourceLabels()); 
    fluent.withSourceNamespace(instance.getSourceNamespace()); 
    fluent.withUri(instance.getUri()); 
    fluent.withWithoutHeaders(instance.getWithoutHeaders()); 
    this.validationEnabled = validationEnabled; 
  }
  public HTTPMatchRequestBuilder(HTTPMatchRequest instance) {
    this(instance,false);
  }
  public HTTPMatchRequestBuilder(HTTPMatchRequest instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAuthority(instance.getAuthority()); 
    this.withGateways(instance.getGateways()); 
    this.withHeaders(instance.getHeaders()); 
    this.withIgnoreUriCase(instance.getIgnoreUriCase()); 
    this.withMethod(instance.getMethod()); 
    this.withName(instance.getName()); 
    this.withPort(instance.getPort()); 
    this.withQueryParams(instance.getQueryParams()); 
    this.withScheme(instance.getScheme()); 
    this.withSourceLabels(instance.getSourceLabels()); 
    this.withSourceNamespace(instance.getSourceNamespace()); 
    this.withUri(instance.getUri()); 
    this.withWithoutHeaders(instance.getWithoutHeaders()); 
    this.validationEnabled = validationEnabled; 
  }
  HTTPMatchRequestFluent<?> fluent;
  Boolean validationEnabled;
  public HTTPMatchRequest build() {
    HTTPMatchRequest buildable = new HTTPMatchRequest(fluent.getAuthority(),fluent.getGateways(),fluent.getHeaders(),fluent.getIgnoreUriCase(),fluent.getMethod(),fluent.getName(),fluent.getPort(),fluent.getQueryParams(),fluent.getScheme(),fluent.getSourceLabels(),fluent.getSourceNamespace(),fluent.getUri(),fluent.getWithoutHeaders());
    return buildable;
  }
  
}
